/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalVar.h"
#include "HvControlSystem.h"
#include "HvControlVar.h"
#include "HvSignalBiquad.h"
#include "HvControlIf.h"
#include "HvControlUnop.h"
#include "HvControlCast.h"
#include "HvControlBinop.h"
#include "HvMath.h"
#include "HvSignalLine.h"
#include "HvControlSlice.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_gN6h8haz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ABh6uRbr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ge9RbsKp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OESjRS3l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Bx48vKiI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_BZvUD7vz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DZ1JxerT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9DkoCVUd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_B8a7JUe1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fhZC0H9T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nu5oWhaS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_01hQC4AX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8wyAo82u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tDUY6Xyi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X8hqhfbt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PoOrgIk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nCtTGNBT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZWUGuYdF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2Fl80hiD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qpy7MnVw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_13vuY05G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F96fGWYd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_byME70Qn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KCOds2mC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Os4jdufF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c09OD82B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x94vkeVq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EBjIhWmh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BrFPCtoO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FwpNFXLD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MhHzfEU8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_io7VuSB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_W8PyWcrU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aT9r2lCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_psDRD0Bg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b2b05wnQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4P9v05RB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xWseMSSj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jgQPuhQP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i5kxDsuf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TK2nyY4G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o1B6Ju4H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X67rgivN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_U4aLHqqD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O6XIu9ZV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Or2PBprI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XgFtjqAl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pecxEBzN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jys2dnQZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Ofc6CTi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o3qcNPxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SIEF7UIm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KIcSpDwc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EmlboQtr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ouQCCx9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_opJmcrJE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XPxj1tzs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WB34ia7Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0SyHrZZq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5TwW2eLv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qq45qx5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HHfo7UOx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pPKL51aR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kZKpopdB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_knrntnVS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hrLNSSYQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_R7pIQA6c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MZ9iBZ9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_baESSRqs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8MAw2tMg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RMRh76UT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oJq2OSfD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JI1wRZum_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mkI5XVaK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JbXDBryf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_15BYHets_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mE4peeV3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uuYXohVA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_np8bASjQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_D2vOlFzU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_byzSx8EJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NBjDn9kq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xmWE311t_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_gbvdZScO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IkzaXePE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_o7BQMtew_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1jI01rvJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4oU8BmPZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1wRskdwz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_blN2t0Iz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pTfcy5Rg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_tmJ3b1S1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mmlnh2bU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_LmuUKXyB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O0LiZoDE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kf8Flxyw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r202wM2G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CAIbbsgX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9SYF4zOF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0wva5DTh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_T69HgSB0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_STRl6kgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EpdOwKdu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sZVooem0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sTheTmGI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1uO8ttU1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BCpYVaCD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SqjAffzt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_uyeIWQ65_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YTF2CSWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WyeNVXjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aFiht55q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dgSHul33_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CRMbgxeZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yZsWFK6G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9kINDuy5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e98PCDiH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_El8B4UJ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1P4prdUy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zmVBVJdL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_77VE3DvF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3HeCxCHG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A6QL0N3J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zUCBzMAO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sSYg8iJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mbqZyJwK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_41kR27DW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DA83HgSb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_uMk1H9Ta_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_EkGZinae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Pp9SoAgD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QYVhaIoD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0c2mh4h4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0SoLVLiQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Iiim16o6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lv5SpBZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u07SzRey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aAuiAkSL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0hl58HmR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7dSsHz1C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BsHmd3fM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eeDn9DA5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EEGLkxBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lEz0SY6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dhRfIv1m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GJbHEJ6W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CZGVMa5P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7Ri7u4Hb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GEbLAmlm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FfbygPNC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l1MY571f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ryzkl05U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L7ePTiSO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7s3y3D5H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bXMVZvK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KfbvpmmI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_61bwlm8w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7vs6cArX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_kyN0sy8D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_25RHDB69_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3b89peDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LbQmp94O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iR6SIIOT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0lvIEzf5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_AdjQm68G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_LQtttQRr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BaTraDO5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jfE3wh0H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_40skbusv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w1AZmNKM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nJskdwZ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0EgJfFnu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0QfwYgUo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P4lfE5Xe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IL2yiPIT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_a4aKgJ4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WlHXGxgf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EsfPJMzH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X8G0dehf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8dgh9d7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_5yz1ny0N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_FwgPNi5r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_kXwK9MaI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gXjBBaeq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VFrl6gIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LrzHYGhL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LYgkk1d9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_azB2AGt1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EGO7Bzez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tjoCmQVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XddxdLS8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UC1oB6G8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e1T0pJAG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NJADlxsE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_efTYFuqs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c77NGOZr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_49MrcZPZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sgR71Fao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6IR3RdyD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FL0dZjxb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gaw9yBHX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VK0gofGj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R5E3yrfe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AUrkBKIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LyOmdklS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3S61KT5m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0hTzmUUY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2Qurlxna_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_k8Vsia5L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j9qXt4NB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hoFVTF7R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DbgdWbsL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kZnH8OCv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_um2abZ6U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_XGikUfsX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_N9RyxuBW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uctoNZi2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S6FX5sSR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g6Sn2QMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CUVL7C1E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pAxNCYz4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MgeV1qMp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aTb5xCjK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fpOa8uTU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AuR0s46W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qZ6E9mhX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9FheAsP1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m4DE9esX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H5wL3onI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GVDwAI0m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e7M6vl9T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_58o4wios_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PAyXHIGO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Qashcxjj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_61uFgprC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fx4U18Sp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MxYt1Prv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_C3PcbxjY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0nteHOzk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GWveexbQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZnjK3z2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J7B2sZzK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L45KK4Bv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vK1aryBi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PA3PltLE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uspVmgnl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n1rQVqs6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_spnjEflm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kpP5eTk4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QyEG76al_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nYuBAHwK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7bOnItCT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v6TTrIlz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_voINO1km_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vTUm5ZqH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fO5RZqZh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jfLpgv2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_davrKjCt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2Vv8ViuJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZD346Qu0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y4hEgBMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q9XDrkLC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MnpOB8Op_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ATtoKJPe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hj26ytLw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LgxDr9hb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_K7pQzNTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Svd4I9Tq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_mMjnPW14_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DJLzb2rd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_TUxanjzZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_C81QyYL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZQZy6gB9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zEuUU9zO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yqaw6ulN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zfeNGkpn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JL7nGk4Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yk2PFmmR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BMrW5aul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_voFDX38M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uR6JTxO7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_y9Yfwaeu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YLfpHrEq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Au0L4gKs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RcywnmE0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eGMewndX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IAcgAxeG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fo5GaMnU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hmjjjMqX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pOrZBMZx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XAAeIRMo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YngziTwk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MFU9f6Ye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oE7k5D4t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9R5LJhfb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NwsXwAMc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aP0CC0w7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yX4TmHQB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5OwHRQE3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7F7oCKQI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AO4U0buB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XXIDtISr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gn6bHv2q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jmf6ezWQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oD87QKfF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0qTH3saV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9SOOlBga_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SLhwi9vU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sdu1YPEu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jT7ni0tx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Llog3019_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IuUYKmDj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fwc0DMRE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ra2N0bKs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h9R4cngF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5Hw9lIQC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xiT1CkJJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qgcC9okp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fZzINhhY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MTVw46FA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YXGg05fI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zhqdaMgd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AcScInlw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R6VlHglZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H36OO1aq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vvwh3Psl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eozbtPk7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QUPpnjWw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MTQ7LeQ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tulIkyI9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vQiqhR3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2PSv0gJy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x7cOCv7H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_21UojJAk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lHWEGEBW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b6Yw7ASe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6g2W2p8m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QkAxngTk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1KyLvB2W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3jr2QZW5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_rUPI5f3S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hotuMu41_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2UfSkv1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JNPY9X9i_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_CZczkq9r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mqpilcUN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_QrbMAMUS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ESaG2P9b_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Zxaf6mQK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_anRNxVaC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_KvEAAuIO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pHjKoHdv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ccpEYZYm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vMemoLW1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UUr43LPI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pIrxHuvB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CtlLDS5d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CUTTHCoB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3CzcjGlu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zIeCvAWW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KIQfqwO5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fQwWgTD8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_AH33Nl5d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IzIWoXJs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HGuNeP9P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8yupvWnw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HRjQVkAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e6i3xj9i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_dCYT38Rv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OE1AQyQz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qk7Bk2I8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_63iYStRs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P6cFr1rz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EFSHkhxj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PWFh5L6W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oaTU3dwu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x2zsjDOJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o734B6BM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2PAcx9UE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MXnAnE5R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tcNONco4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GPctfgLx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fkn3J62V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VuNr3GlL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7SEI99ti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RfWoryZj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_knsTz29Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X16O8bly_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GkanB1hZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ew3W4oEM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_QnJi5fli_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ESoABtic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kK8DoUCm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8aUNPDiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oNFkMcyf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jZpX1sgO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u6GF3Syn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hfs40Zs2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zi1Ri1c3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EFke5nRx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JnmrMSAD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4z1yH0Rf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KzSbLcLp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XZZuZss8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZX7zhT1P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MekzQPkG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fpOMYIm6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AswwV8dD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HyMocbrW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MmVjfSbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8LE1sAj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UKvG33yk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LN6Ttq7e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k4829p9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ct8aEYMq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DlIcfTfx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FfyK0TuG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7ysHfysq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sWABSubI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_4nAslNzX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t5uMW9am_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vMzUQCE8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3FTTUwUB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_loVEeYpm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hYdyiPJZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_IAAujLrs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_C5PfGFws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G9tHC20e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cIGSYzOL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rkBqdQti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X8oiZZIf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qrbIcvEA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oqmv2iI2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y7WqqOkU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XNyMp7CO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dj1pIYAU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hGJ82PVy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3bLx09g5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zGzchjBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dbjEPUEU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_83XjpXNd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UHimcngZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_dYGgemlo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_SmKaZqUg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7hoHEleT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5TEKVmVk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rE3HEx0M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zMOk1izi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YSoHurPe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xSFnkUtQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oNsytOBI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gWdWqtay_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ELjxC543_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ExzWa19a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Nuo4fuSQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OlPCLNdJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mqyh8r9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wAGWc3fC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tfdE9mKf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zqpbDi3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WplT49Un_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KCnmrmAl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H8BSt3MX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QZdsEbcR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IwB04nwh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mP8sIe3U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q4wRt6uJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iCWlP8Ul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sBkwQRNk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Dff2VMTq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KcgOjJgc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jxHDJxWx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_stfwrHb8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_12TMs3ge_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6afRj0Sw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_BLhZg9RY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_R1nXDVmN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X5f6eH4N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qUtFFJgx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PLbeVXq4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8bGKisxh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JkkhgRff_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GNn4semo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HK78TCKb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yxRri70F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HqsTXllo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q6WS1HPj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xj4GgItm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jOJyEwPh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AAhyXzq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1cavxdg8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CxDB2Wqa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CZluMWJn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zPCDSip7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jdFffESh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ogRMFewQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gfwBcZXI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y6Mql671_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6E7qHdST_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_BfEhvPcF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JYUpAyPn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QVgq7clc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eJkHRPx8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WQA81ahN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DllCtevG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uer0gGvh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JVaNzC6m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wz9axmjp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9NUdwEdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Pp9odlVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IVaGoFR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_snylNeej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zVG6nGEc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TddvM89F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NL1eY3XL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vS4AxX3X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G08zKkxS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ft9yxzfS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YUwDimhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6UTXFAzh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HFm0fO6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gmXLonFH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nnddJU4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W2Z4iRdT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WDZeiumK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FaHP4WPe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KzHQnDUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TCbEQD4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_BBSKnBRT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_eAkyRZlh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IjCiRK7z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_e7WfmGKT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rySmxg4T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p8b3amA4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oPca7Boq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cbEsKfFC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_HXhyrRUt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tY5bBIKl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ev3Rw4qm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v7P9J8pB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ELFZKilK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cf1NJcH0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4ckWfarA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Stc4qpQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LivcMNfq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R3URWWoc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7yciC4Gy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MYRXL80c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eg6cvHwY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RdWe1MHw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kOdBKszY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_n9RcMn9w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mkKyLLlz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OEw7lFEG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Kuql4jk9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bHT6b6Dk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ob8l6MWw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yi3InJRN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ke1U2lvl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_twno4ieP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Yc6HlPda_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PJ7uF7N1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_58D2U5dy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ndMvRUhL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6Yy4Ky77_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_u3jSMjFK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QGUZur1y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dBs8RbBS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pgxPhAPF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BvvSnSiz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UUMzZcTV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FRqbROLU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wga74e5A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ke9HtmH6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Wbbd6JbF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AYULEmFC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UMSjAqQI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MgIyOYEV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_byagjLtb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6mufYVyZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aDo4vNAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_VDPKMfIf;
  SignalLine sLine_NAxZY5YG;
  SignalLine sLine_UceFbHCP;
  SignalLine sLine_uU4KbDMF;
  SignalLine sLine_IOUokYM7;
  SignalBiquad sBiquad_s_WV4oox60;
  SignalLine sLine_xLcaJbNo;
  SignalLine sLine_M3WYavmK;
  SignalLine sLine_urYy4T2c;
  SignalLine sLine_72L0f8HJ;
  SignalBiquad sBiquad_s_KPEMtLMM;
  SignalLine sLine_WLdnOEQN;
  SignalLine sLine_da6TPVh5;
  SignalLine sLine_vo8griwJ;
  SignalLine sLine_dCXDzunI;
  SignalLine sLine_ZHwLdgRy;
  SignalBiquad sBiquad_s_ZCyZ7xgD;
  SignalLine sLine_LxThGQSg;
  SignalLine sLine_gluMmNLA;
  SignalLine sLine_kpo1BBSc;
  SignalLine sLine_msutQeJO;
  SignalLine sLine_D32j5R5I;
  SignalBiquad sBiquad_s_Js4HZYeo;
  SignalLine sLine_1m80Q8at;
  SignalLine sLine_UHRdj6b3;
  SignalLine sLine_quprpcAq;
  SignalLine sLine_Loqi00Ap;
  SignalBiquad sBiquad_s_1R7rl3X0;
  SignalLine sLine_5EVc3t1N;
  SignalLine sLine_6vOzTu2R;
  SignalLine sLine_W6nIBOJI;
  SignalLine sLine_LsCXjWuy;
  SignalLine sLine_jXnJz9lh;
  SignalBiquad sBiquad_s_TzICuMUo;
  ControlVar cVar_gN6h8haz;
  ControlVar cVar_ABh6uRbr;
  ControlVar cVar_Ge9RbsKp;
  ControlVar cVar_OESjRS3l;
  ControlSlice cSlice_BZvUD7vz;
  ControlVar cVar_DZ1JxerT;
  ControlVar cVar_B8a7JUe1;
  ControlIf cIf_fhZC0H9T;
  ControlIf cIf_nu5oWhaS;
  ControlBinop cBinop_8wyAo82u;
  ControlBinop cBinop_tDUY6Xyi;
  ControlBinop cBinop_nCtTGNBT;
  ControlBinop cBinop_ZWUGuYdF;
  ControlBinop cBinop_qpy7MnVw;
  ControlIf cIf_13vuY05G;
  ControlBinop cBinop_F96fGWYd;
  ControlBinop cBinop_byME70Qn;
  ControlBinop cBinop_Os4jdufF;
  ControlBinop cBinop_c09OD82B;
  ControlBinop cBinop_x94vkeVq;
  ControlVar cVar_io7VuSB2;
  ControlIf cIf_W8PyWcrU;
  ControlIf cIf_aT9r2lCJ;
  ControlBinop cBinop_b2b05wnQ;
  ControlBinop cBinop_4P9v05RB;
  ControlBinop cBinop_i5kxDsuf;
  ControlBinop cBinop_TK2nyY4G;
  ControlBinop cBinop_X67rgivN;
  ControlIf cIf_U4aLHqqD;
  ControlBinop cBinop_O6XIu9ZV;
  ControlBinop cBinop_Or2PBprI;
  ControlBinop cBinop_pecxEBzN;
  ControlBinop cBinop_Jys2dnQZ;
  ControlBinop cBinop_2Ofc6CTi;
  ControlVar cVar_ouQCCx9u;
  ControlIf cIf_opJmcrJE;
  ControlIf cIf_XPxj1tzs;
  ControlBinop cBinop_0SyHrZZq;
  ControlBinop cBinop_5TwW2eLv;
  ControlBinop cBinop_pPKL51aR;
  ControlBinop cBinop_kZKpopdB;
  ControlBinop cBinop_hrLNSSYQ;
  ControlIf cIf_R7pIQA6c;
  ControlBinop cBinop_MZ9iBZ9u;
  ControlBinop cBinop_baESSRqs;
  ControlBinop cBinop_RMRh76UT;
  ControlBinop cBinop_oJq2OSfD;
  ControlBinop cBinop_JI1wRZum;
  ControlIf cIf_uuYXohVA;
  ControlSlice cSlice_D2vOlFzU;
  ControlVar cVar_byzSx8EJ;
  ControlSlice cSlice_gbvdZScO;
  ControlVar cVar_IkzaXePE;
  ControlSlice cSlice_4oU8BmPZ;
  ControlVar cVar_1wRskdwz;
  ControlSlice cSlice_tmJ3b1S1;
  ControlVar cVar_mmlnh2bU;
  ControlBinop cBinop_sZVooem0;
  ControlBinop cBinop_1uO8ttU1;
  ControlBinop cBinop_BCpYVaCD;
  ControlBinop cBinop_YTF2CSWN;
  ControlBinop cBinop_WyeNVXjc;
  ControlBinop cBinop_aFiht55q;
  ControlBinop cBinop_dgSHul33;
  ControlBinop cBinop_CRMbgxeZ;
  ControlVar cVar_yZsWFK6G;
  ControlBinop cBinop_9kINDuy5;
  ControlBinop cBinop_e98PCDiH;
  ControlBinop cBinop_El8B4UJ5;
  ControlBinop cBinop_1P4prdUy;
  ControlBinop cBinop_zmVBVJdL;
  ControlBinop cBinop_77VE3DvF;
  ControlBinop cBinop_3HeCxCHG;
  ControlBinop cBinop_zUCBzMAO;
  ControlVar cVar_sSYg8iJu;
  ControlVar cVar_mbqZyJwK;
  ControlBinop cBinop_0c2mh4h4;
  ControlBinop cBinop_0SoLVLiQ;
  ControlBinop cBinop_Iiim16o6;
  ControlBinop cBinop_u07SzRey;
  ControlBinop cBinop_aAuiAkSL;
  ControlBinop cBinop_0hl58HmR;
  ControlBinop cBinop_7dSsHz1C;
  ControlBinop cBinop_BsHmd3fM;
  ControlBinop cBinop_eeDn9DA5;
  ControlBinop cBinop_3b89peDy;
  ControlBinop cBinop_iR6SIIOT;
  ControlBinop cBinop_0lvIEzf5;
  ControlBinop cBinop_BaTraDO5;
  ControlBinop cBinop_jfE3wh0H;
  ControlBinop cBinop_40skbusv;
  ControlBinop cBinop_w1AZmNKM;
  ControlBinop cBinop_nJskdwZ0;
  ControlBinop cBinop_0EgJfFnu;
  ControlBinop cBinop_0QfwYgUo;
  ControlBinop cBinop_IL2yiPIT;
  ControlVar cVar_a4aKgJ4W;
  ControlVar cVar_WlHXGxgf;
  ControlVar cVar_EsfPJMzH;
  ControlBinop cBinop_VFrl6gIW;
  ControlBinop cBinop_LrzHYGhL;
  ControlBinop cBinop_LYgkk1d9;
  ControlBinop cBinop_EGO7Bzez;
  ControlBinop cBinop_tjoCmQVJ;
  ControlBinop cBinop_XddxdLS8;
  ControlBinop cBinop_UC1oB6G8;
  ControlBinop cBinop_e1T0pJAG;
  ControlBinop cBinop_hoFVTF7R;
  ControlBinop cBinop_kZnH8OCv;
  ControlBinop cBinop_um2abZ6U;
  ControlBinop cBinop_uctoNZi2;
  ControlBinop cBinop_S6FX5sSR;
  ControlBinop cBinop_g6Sn2QMj;
  ControlBinop cBinop_CUVL7C1E;
  ControlBinop cBinop_pAxNCYz4;
  ControlBinop cBinop_aTb5xCjK;
  ControlBinop cBinop_AuR0s46W;
  ControlBinop cBinop_qZ6E9mhX;
  ControlBinop cBinop_m4DE9esX;
  ControlBinop cBinop_H5wL3onI;
  ControlBinop cBinop_GVDwAI0m;
  ControlBinop cBinop_58o4wios;
  ControlVar cVar_PAyXHIGO;
  ControlVar cVar_Qashcxjj;
  ControlVar cVar_61uFgprC;
  ControlBinop cBinop_J7B2sZzK;
  ControlBinop cBinop_L45KK4Bv;
  ControlBinop cBinop_vK1aryBi;
  ControlBinop cBinop_uspVmgnl;
  ControlBinop cBinop_n1rQVqs6;
  ControlBinop cBinop_spnjEflm;
  ControlBinop cBinop_kpP5eTk4;
  ControlBinop cBinop_QyEG76al;
  ControlBinop cBinop_nYuBAHwK;
  ControlBinop cBinop_q9XDrkLC;
  ControlBinop cBinop_ATtoKJPe;
  ControlBinop cBinop_Hj26ytLw;
  SignalVarf sVarf_eTZaZwKU;
  SignalVarf sVarf_SiSifHCm;
  SignalVarf sVarf_TJWqoDAe;
  ControlSlice cSlice_K7pQzNTY;
  ControlVar cVar_Svd4I9Tq;
  ControlVar cVar_DJLzb2rd;
  ControlIf cIf_TUxanjzZ;
  ControlIf cIf_C81QyYL3;
  ControlBinop cBinop_zEuUU9zO;
  ControlBinop cBinop_Yqaw6ulN;
  ControlBinop cBinop_yk2PFmmR;
  ControlBinop cBinop_BMrW5aul;
  ControlBinop cBinop_uR6JTxO7;
  ControlIf cIf_y9Yfwaeu;
  ControlBinop cBinop_YLfpHrEq;
  ControlBinop cBinop_Au0L4gKs;
  ControlBinop cBinop_eGMewndX;
  ControlBinop cBinop_IAcgAxeG;
  ControlBinop cBinop_fo5GaMnU;
  ControlVar cVar_MFU9f6Ye;
  ControlIf cIf_oE7k5D4t;
  ControlIf cIf_9R5LJhfb;
  ControlBinop cBinop_aP0CC0w7;
  ControlBinop cBinop_yX4TmHQB;
  ControlBinop cBinop_AO4U0buB;
  ControlBinop cBinop_XXIDtISr;
  ControlBinop cBinop_Jmf6ezWQ;
  ControlIf cIf_oD87QKfF;
  ControlBinop cBinop_0qTH3saV;
  ControlBinop cBinop_9SOOlBga;
  ControlBinop cBinop_sdu1YPEu;
  ControlBinop cBinop_jT7ni0tx;
  ControlBinop cBinop_Llog3019;
  ControlVar cVar_5Hw9lIQC;
  ControlIf cIf_xiT1CkJJ;
  ControlIf cIf_qgcC9okp;
  ControlBinop cBinop_MTVw46FA;
  ControlBinop cBinop_YXGg05fI;
  ControlBinop cBinop_R6VlHglZ;
  ControlBinop cBinop_H36OO1aq;
  ControlBinop cBinop_eozbtPk7;
  ControlIf cIf_QUPpnjWw;
  ControlBinop cBinop_MTQ7LeQ1;
  ControlBinop cBinop_tulIkyI9;
  ControlBinop cBinop_2PSv0gJy;
  ControlBinop cBinop_x7cOCv7H;
  ControlBinop cBinop_21UojJAk;
  ControlIf cIf_1KyLvB2W;
  ControlSlice cSlice_rUPI5f3S;
  ControlVar cVar_hotuMu41;
  ControlSlice cSlice_CZczkq9r;
  ControlVar cVar_mqpilcUN;
  ControlSlice cSlice_Zxaf6mQK;
  ControlVar cVar_anRNxVaC;
  ControlSlice cSlice_ccpEYZYm;
  ControlVar cVar_vMemoLW1;
  ControlBinop cBinop_HGuNeP9P;
  ControlBinop cBinop_HRjQVkAL;
  ControlBinop cBinop_e6i3xj9i;
  ControlBinop cBinop_qk7Bk2I8;
  ControlBinop cBinop_63iYStRs;
  ControlBinop cBinop_P6cFr1rz;
  ControlBinop cBinop_EFSHkhxj;
  ControlBinop cBinop_PWFh5L6W;
  ControlVar cVar_oaTU3dwu;
  ControlBinop cBinop_x2zsjDOJ;
  ControlBinop cBinop_o734B6BM;
  ControlBinop cBinop_2PAcx9UE;
  ControlBinop cBinop_MXnAnE5R;
  ControlBinop cBinop_tcNONco4;
  ControlBinop cBinop_GPctfgLx;
  ControlBinop cBinop_Fkn3J62V;
  ControlBinop cBinop_7SEI99ti;
  ControlVar cVar_RfWoryZj;
  ControlVar cVar_knsTz29Z;
  ControlBinop cBinop_8aUNPDiy;
  ControlBinop cBinop_oNFkMcyf;
  ControlBinop cBinop_jZpX1sgO;
  ControlBinop cBinop_hfs40Zs2;
  ControlBinop cBinop_zi1Ri1c3;
  ControlBinop cBinop_EFke5nRx;
  ControlBinop cBinop_JnmrMSAD;
  ControlBinop cBinop_4z1yH0Rf;
  ControlBinop cBinop_KzSbLcLp;
  ControlBinop cBinop_vMzUQCE8;
  ControlBinop cBinop_loVEeYpm;
  ControlBinop cBinop_hYdyiPJZ;
  ControlBinop cBinop_G9tHC20e;
  ControlBinop cBinop_cIGSYzOL;
  ControlBinop cBinop_rkBqdQti;
  ControlBinop cBinop_X8oiZZIf;
  ControlBinop cBinop_qrbIcvEA;
  ControlBinop cBinop_oqmv2iI2;
  ControlBinop cBinop_y7WqqOkU;
  ControlBinop cBinop_Dj1pIYAU;
  ControlVar cVar_hGJ82PVy;
  ControlVar cVar_3bLx09g5;
  ControlVar cVar_zGzchjBO;
  ControlBinop cBinop_5TEKVmVk;
  ControlBinop cBinop_rE3HEx0M;
  ControlBinop cBinop_zMOk1izi;
  ControlBinop cBinop_xSFnkUtQ;
  ControlBinop cBinop_oNsytOBI;
  ControlBinop cBinop_gWdWqtay;
  ControlBinop cBinop_ELjxC543;
  ControlBinop cBinop_ExzWa19a;
  ControlBinop cBinop_jxHDJxWx;
  ControlBinop cBinop_12TMs3ge;
  ControlBinop cBinop_6afRj0Sw;
  ControlBinop cBinop_X5f6eH4N;
  ControlBinop cBinop_qUtFFJgx;
  ControlBinop cBinop_PLbeVXq4;
  ControlBinop cBinop_8bGKisxh;
  ControlBinop cBinop_JkkhgRff;
  ControlBinop cBinop_HK78TCKb;
  ControlBinop cBinop_HqsTXllo;
  ControlBinop cBinop_Q6WS1HPj;
  ControlBinop cBinop_jOJyEwPh;
  ControlBinop cBinop_AAhyXzq1;
  ControlBinop cBinop_1cavxdg8;
  ControlBinop cBinop_CZluMWJn;
  ControlVar cVar_zPCDSip7;
  ControlVar cVar_jdFffESh;
  ControlVar cVar_ogRMFewQ;
  ControlBinop cBinop_eJkHRPx8;
  ControlBinop cBinop_WQA81ahN;
  ControlBinop cBinop_DllCtevG;
  ControlBinop cBinop_JVaNzC6m;
  ControlBinop cBinop_Wz9axmjp;
  ControlBinop cBinop_9NUdwEdo;
  ControlBinop cBinop_Pp9odlVr;
  ControlBinop cBinop_IVaGoFR1;
  ControlBinop cBinop_snylNeej;
  ControlBinop cBinop_nnddJU4M;
  ControlBinop cBinop_WDZeiumK;
  ControlBinop cBinop_FaHP4WPe;
  SignalVarf sVarf_VO7klY9S;
  SignalVarf sVarf_rYyDPOsv;
  SignalVarf sVarf_m5fhGUVC;
  SignalVarf sVarf_5gbsBtbI;
  SignalVarf sVarf_i0VqjcpW;
  SignalVarf sVarf_559h1Yrq;
  SignalVarf sVarf_BRgvXACv;
  SignalVarf sVarf_oGu4r2Up;
  SignalVarf sVarf_RqjDwdM2;
  ControlVar cVar_KzHQnDUP;
  ControlVar cVar_TCbEQD4M;
  ControlBinop cBinop_p8b3amA4;
  ControlBinop cBinop_oPca7Boq;
  ControlBinop cBinop_cbEsKfFC;
  ControlBinop cBinop_tY5bBIKl;
  ControlBinop cBinop_ev3Rw4qm;
  ControlBinop cBinop_v7P9J8pB;
  ControlBinop cBinop_ELFZKilK;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
