/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_VDPKMfIf);
  numBytes += sLine_init(&sLine_NAxZY5YG);
  numBytes += sLine_init(&sLine_UceFbHCP);
  numBytes += sLine_init(&sLine_uU4KbDMF);
  numBytes += sLine_init(&sLine_IOUokYM7);
  numBytes += sBiquad_init(&sBiquad_s_WV4oox60);
  numBytes += sLine_init(&sLine_xLcaJbNo);
  numBytes += sLine_init(&sLine_M3WYavmK);
  numBytes += sLine_init(&sLine_urYy4T2c);
  numBytes += sLine_init(&sLine_72L0f8HJ);
  numBytes += sBiquad_init(&sBiquad_s_KPEMtLMM);
  numBytes += sLine_init(&sLine_WLdnOEQN);
  numBytes += sLine_init(&sLine_da6TPVh5);
  numBytes += sLine_init(&sLine_vo8griwJ);
  numBytes += sLine_init(&sLine_dCXDzunI);
  numBytes += sLine_init(&sLine_ZHwLdgRy);
  numBytes += sBiquad_init(&sBiquad_s_ZCyZ7xgD);
  numBytes += sLine_init(&sLine_LxThGQSg);
  numBytes += sLine_init(&sLine_gluMmNLA);
  numBytes += sLine_init(&sLine_kpo1BBSc);
  numBytes += sLine_init(&sLine_msutQeJO);
  numBytes += sLine_init(&sLine_D32j5R5I);
  numBytes += sBiquad_init(&sBiquad_s_Js4HZYeo);
  numBytes += sLine_init(&sLine_1m80Q8at);
  numBytes += sLine_init(&sLine_UHRdj6b3);
  numBytes += sLine_init(&sLine_quprpcAq);
  numBytes += sLine_init(&sLine_Loqi00Ap);
  numBytes += sBiquad_init(&sBiquad_s_1R7rl3X0);
  numBytes += sLine_init(&sLine_5EVc3t1N);
  numBytes += sLine_init(&sLine_6vOzTu2R);
  numBytes += sLine_init(&sLine_W6nIBOJI);
  numBytes += sLine_init(&sLine_LsCXjWuy);
  numBytes += sLine_init(&sLine_jXnJz9lh);
  numBytes += sBiquad_init(&sBiquad_s_TzICuMUo);
  numBytes += cVar_init_f(&cVar_gN6h8haz, 0.0f);
  numBytes += cVar_init_f(&cVar_ABh6uRbr, 0.0f);
  numBytes += cVar_init_f(&cVar_Ge9RbsKp, 0.0f);
  numBytes += cVar_init_f(&cVar_OESjRS3l, 0.0f);
  numBytes += cSlice_init(&cSlice_BZvUD7vz, 1, -1);
  numBytes += cVar_init_f(&cVar_DZ1JxerT, 1337.0f);
  numBytes += cVar_init_f(&cVar_B8a7JUe1, 0.0f);
  numBytes += cIf_init(&cIf_fhZC0H9T, false);
  numBytes += cIf_init(&cIf_nu5oWhaS, false);
  numBytes += cBinop_init(&cBinop_8wyAo82u, 0.0f); // __pow
  numBytes += cIf_init(&cIf_13vuY05G, false);
  numBytes += cBinop_init(&cBinop_Os4jdufF, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_c09OD82B, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_x94vkeVq, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_io7VuSB2, 0.0f);
  numBytes += cIf_init(&cIf_W8PyWcrU, false);
  numBytes += cIf_init(&cIf_aT9r2lCJ, false);
  numBytes += cBinop_init(&cBinop_b2b05wnQ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_U4aLHqqD, false);
  numBytes += cBinop_init(&cBinop_pecxEBzN, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Jys2dnQZ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_2Ofc6CTi, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ouQCCx9u, 0.0f);
  numBytes += cIf_init(&cIf_opJmcrJE, false);
  numBytes += cIf_init(&cIf_XPxj1tzs, false);
  numBytes += cBinop_init(&cBinop_0SyHrZZq, 0.0f); // __pow
  numBytes += cIf_init(&cIf_R7pIQA6c, false);
  numBytes += cBinop_init(&cBinop_RMRh76UT, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_oJq2OSfD, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_JI1wRZum, -15.0f); // __eq
  numBytes += cIf_init(&cIf_uuYXohVA, false);
  numBytes += cSlice_init(&cSlice_D2vOlFzU, 1, -1);
  numBytes += cVar_init_f(&cVar_byzSx8EJ, 0.0f);
  numBytes += cSlice_init(&cSlice_gbvdZScO, 1, -1);
  numBytes += cVar_init_f(&cVar_IkzaXePE, 0.0f);
  numBytes += cSlice_init(&cSlice_4oU8BmPZ, 1, -1);
  numBytes += cVar_init_f(&cVar_1wRskdwz, 0.0f);
  numBytes += cSlice_init(&cSlice_tmJ3b1S1, 1, -1);
  numBytes += cVar_init_f(&cVar_mmlnh2bU, 0.313f);
  numBytes += cBinop_init(&cBinop_1uO8ttU1, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_BCpYVaCD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_yZsWFK6G, 0.0f);
  numBytes += cVar_init_f(&cVar_sSYg8iJu, 1337.0f);
  numBytes += cVar_init_f(&cVar_mbqZyJwK, 0.3f);
  numBytes += cBinop_init(&cBinop_0SoLVLiQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aAuiAkSL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0hl58HmR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7dSsHz1C, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BsHmd3fM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eeDn9DA5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iR6SIIOT, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_0lvIEzf5, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_a4aKgJ4W, 0.0f);
  numBytes += cVar_init_f(&cVar_WlHXGxgf, 1337.0f);
  numBytes += cVar_init_f(&cVar_EsfPJMzH, 0.313f);
  numBytes += cBinop_init(&cBinop_LrzHYGhL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tjoCmQVJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XddxdLS8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UC1oB6G8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_e1T0pJAG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kZnH8OCv, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_um2abZ6U, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_PAyXHIGO, 0.0f);
  numBytes += cVar_init_f(&cVar_Qashcxjj, 1037.0f);
  numBytes += cVar_init_f(&cVar_61uFgprC, 0.4f);
  numBytes += cBinop_init(&cBinop_L45KK4Bv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_n1rQVqs6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_spnjEflm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kpP5eTk4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QyEG76al, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nYuBAHwK, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_eTZaZwKU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SiSifHCm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TJWqoDAe, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_K7pQzNTY, 1, -1);
  numBytes += cVar_init_f(&cVar_Svd4I9Tq, 1337.0f);
  numBytes += cVar_init_f(&cVar_DJLzb2rd, 0.0f);
  numBytes += cIf_init(&cIf_TUxanjzZ, false);
  numBytes += cIf_init(&cIf_C81QyYL3, false);
  numBytes += cBinop_init(&cBinop_zEuUU9zO, 0.0f); // __pow
  numBytes += cIf_init(&cIf_y9Yfwaeu, false);
  numBytes += cBinop_init(&cBinop_eGMewndX, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_IAcgAxeG, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_fo5GaMnU, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_MFU9f6Ye, 0.0f);
  numBytes += cIf_init(&cIf_oE7k5D4t, false);
  numBytes += cIf_init(&cIf_9R5LJhfb, false);
  numBytes += cBinop_init(&cBinop_aP0CC0w7, 0.0f); // __pow
  numBytes += cIf_init(&cIf_oD87QKfF, false);
  numBytes += cBinop_init(&cBinop_sdu1YPEu, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_jT7ni0tx, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Llog3019, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_5Hw9lIQC, 0.0f);
  numBytes += cIf_init(&cIf_xiT1CkJJ, false);
  numBytes += cIf_init(&cIf_qgcC9okp, false);
  numBytes += cBinop_init(&cBinop_MTVw46FA, 0.0f); // __pow
  numBytes += cIf_init(&cIf_QUPpnjWw, false);
  numBytes += cBinop_init(&cBinop_2PSv0gJy, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_x7cOCv7H, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_21UojJAk, -15.0f); // __eq
  numBytes += cIf_init(&cIf_1KyLvB2W, false);
  numBytes += cSlice_init(&cSlice_rUPI5f3S, 1, -1);
  numBytes += cVar_init_f(&cVar_hotuMu41, 0.0f);
  numBytes += cSlice_init(&cSlice_CZczkq9r, 1, -1);
  numBytes += cVar_init_f(&cVar_mqpilcUN, 0.0f);
  numBytes += cSlice_init(&cSlice_Zxaf6mQK, 1, -1);
  numBytes += cVar_init_f(&cVar_anRNxVaC, 0.0f);
  numBytes += cSlice_init(&cSlice_ccpEYZYm, 1, -1);
  numBytes += cVar_init_f(&cVar_vMemoLW1, 0.313f);
  numBytes += cBinop_init(&cBinop_HRjQVkAL, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_e6i3xj9i, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_oaTU3dwu, 0.0f);
  numBytes += cVar_init_f(&cVar_RfWoryZj, 1337.0f);
  numBytes += cVar_init_f(&cVar_knsTz29Z, 0.3f);
  numBytes += cBinop_init(&cBinop_oNFkMcyf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zi1Ri1c3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EFke5nRx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JnmrMSAD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4z1yH0Rf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KzSbLcLp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_loVEeYpm, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_hYdyiPJZ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_hGJ82PVy, 0.0f);
  numBytes += cVar_init_f(&cVar_3bLx09g5, 1337.0f);
  numBytes += cVar_init_f(&cVar_zGzchjBO, 0.313f);
  numBytes += cBinop_init(&cBinop_rE3HEx0M, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oNsytOBI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gWdWqtay, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ELjxC543, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ExzWa19a, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_12TMs3ge, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_6afRj0Sw, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_zPCDSip7, 0.0f);
  numBytes += cVar_init_f(&cVar_jdFffESh, 1037.0f);
  numBytes += cVar_init_f(&cVar_ogRMFewQ, 0.4f);
  numBytes += cBinop_init(&cBinop_WQA81ahN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Wz9axmjp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9NUdwEdo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Pp9odlVr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IVaGoFR1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_snylNeej, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VO7klY9S, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rYyDPOsv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_m5fhGUVC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5gbsBtbI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_i0VqjcpW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_559h1Yrq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BRgvXACv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oGu4r2Up, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RqjDwdM2, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_KzHQnDUP, 5705.6f);
  numBytes += cVar_init_f(&cVar_TCbEQD4M, 313.3f);
  numBytes += cBinop_init(&cBinop_p8b3amA4, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_oPca7Boq, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_cbEsKfFC, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eg6cvHwY_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kOdBKszY_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RdWe1MHw_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aDo4vNAy_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OEw7lFEG_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Kuql4jk9_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n9RcMn9w_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mkKyLLlz_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bHT6b6Dk_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_twno4ieP_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ke1U2lvl_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yi3InJRN_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_58D2U5dy_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PJ7uF7N1_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Yc6HlPda_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_u3jSMjFK_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6Yy4Ky77_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ndMvRUhL_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pgxPhAPF_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BvvSnSiz_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QGUZur1y_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dBs8RbBS_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UUMzZcTV_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ke9HtmH6_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wga74e5A_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FRqbROLU_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UMSjAqQI_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AYULEmFC_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Wbbd6JbF_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6mufYVyZ_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_byagjLtb_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MgIyOYEV_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ob8l6MWw_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_gN6h8haz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cf1NJcH0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ABh6uRbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4ckWfarA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Ge9RbsKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Stc4qpQy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_OESjRS3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LivcMNfq_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rySmxg4T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IjCiRK7z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e7WfmGKT_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_Bx48vKiI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BZvUD7vz, 0, m, &cSlice_BZvUD7vz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1jI01rvJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_BZvUD7vz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9DkoCVUd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9DkoCVUd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_DZ1JxerT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9DkoCVUd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_9DkoCVUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_n9RcMn9w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_B8a7JUe1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_F96fGWYd_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_fhZC0H9T, 0, m, &cIf_fhZC0H9T_sendMessage);
}

void Heavy_WSTD_EQ::cIf_fhZC0H9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_byME70Qn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_nu5oWhaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_2Fl80hiD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ZWUGuYdF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_01hQC4AX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8wyAo82u, HV_BINOP_POW, 0, m, &cBinop_8wyAo82u_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8wyAo82u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_13vuY05G, 0, m, &cIf_13vuY05G_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tDUY6Xyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_qpy7MnVw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_X8hqhfbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nu5oWhaS, 0, m, &cIf_nu5oWhaS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PoOrgIk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nCtTGNBT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nCtTGNBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nu5oWhaS, 1, m, &cIf_nu5oWhaS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZWUGuYdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_tDUY6Xyi_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2Fl80hiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_13vuY05G, 0, m, &cIf_13vuY05G_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qpy7MnVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8wyAo82u, HV_BINOP_POW, 1, m, &cBinop_8wyAo82u_sendMessage);
  cMsg_01hQC4AX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_13vuY05G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_eTZaZwKU, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_F96fGWYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fhZC0H9T, 1, m, &cIf_fhZC0H9T_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_byME70Qn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c09OD82B, HV_BINOP_GREATER_THAN, 1, m, &cBinop_c09OD82B_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_x94vkeVq, HV_BINOP_EQ, 1, m, &cBinop_x94vkeVq_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_KCOds2mC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Os4jdufF, HV_BINOP_ADD, 0, m, &cBinop_Os4jdufF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Os4jdufF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PoOrgIk8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X8hqhfbt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_c09OD82B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_13vuY05G, 1, m, &cIf_13vuY05G_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_x94vkeVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EBjIhWmh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_EBjIhWmh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eTZaZwKU, m);
}

void Heavy_WSTD_EQ::cCast_BrFPCtoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_B8a7JUe1, 0, m, &cVar_B8a7JUe1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FwpNFXLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KCOds2mC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_MhHzfEU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Os4jdufF, HV_BINOP_ADD, 1, m, &cBinop_Os4jdufF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_c09OD82B, HV_BINOP_GREATER_THAN, 0, m, &cBinop_c09OD82B_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_x94vkeVq, HV_BINOP_EQ, 0, m, &cBinop_x94vkeVq_sendMessage);
}

void Heavy_WSTD_EQ::cVar_io7VuSB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_O6XIu9ZV_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_W8PyWcrU, 0, m, &cIf_W8PyWcrU_sendMessage);
}

void Heavy_WSTD_EQ::cIf_W8PyWcrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Or2PBprI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_aT9r2lCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_o1B6Ju4H_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_TK2nyY4G_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_psDRD0Bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_b2b05wnQ, HV_BINOP_POW, 0, m, &cBinop_b2b05wnQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_b2b05wnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U4aLHqqD, 0, m, &cIf_U4aLHqqD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4P9v05RB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_X67rgivN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xWseMSSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_i5kxDsuf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jgQPuhQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aT9r2lCJ, 0, m, &cIf_aT9r2lCJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_i5kxDsuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aT9r2lCJ, 1, m, &cIf_aT9r2lCJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TK2nyY4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_4P9v05RB_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_o1B6Ju4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_U4aLHqqD, 0, m, &cIf_U4aLHqqD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_X67rgivN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b2b05wnQ, HV_BINOP_POW, 1, m, &cBinop_b2b05wnQ_sendMessage);
  cMsg_psDRD0Bg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_U4aLHqqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_q9XDrkLC_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ATtoKJPe_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Hj26ytLw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_O6XIu9ZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_W8PyWcrU, 1, m, &cIf_W8PyWcrU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Or2PBprI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jys2dnQZ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Jys2dnQZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Ofc6CTi, HV_BINOP_EQ, 1, m, &cBinop_2Ofc6CTi_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_XgFtjqAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pecxEBzN, HV_BINOP_ADD, 0, m, &cBinop_pecxEBzN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pecxEBzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xWseMSSj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jgQPuhQP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Jys2dnQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U4aLHqqD, 1, m, &cIf_U4aLHqqD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2Ofc6CTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o3qcNPxL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_o3qcNPxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_q9XDrkLC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ATtoKJPe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Hj26ytLw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SIEF7UIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XgFtjqAl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_KIcSpDwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pecxEBzN, HV_BINOP_ADD, 1, m, &cBinop_pecxEBzN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jys2dnQZ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Jys2dnQZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Ofc6CTi, HV_BINOP_EQ, 0, m, &cBinop_2Ofc6CTi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EmlboQtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_io7VuSB2, 0, m, &cVar_io7VuSB2_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ouQCCx9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MZ9iBZ9u_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_opJmcrJE, 0, m, &cIf_opJmcrJE_sendMessage);
}

void Heavy_WSTD_EQ::cIf_opJmcrJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_baESSRqs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_XPxj1tzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_knrntnVS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_kZKpopdB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_WB34ia7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0SyHrZZq, HV_BINOP_POW, 0, m, &cBinop_0SyHrZZq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0SyHrZZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R7pIQA6c, 0, m, &cIf_R7pIQA6c_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5TwW2eLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_hrLNSSYQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qq45qx5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XPxj1tzs, 0, m, &cIf_XPxj1tzs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HHfo7UOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pPKL51aR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pPKL51aR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XPxj1tzs, 1, m, &cIf_XPxj1tzs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kZKpopdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_5TwW2eLv_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_knrntnVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_R7pIQA6c, 0, m, &cIf_R7pIQA6c_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hrLNSSYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0SyHrZZq, HV_BINOP_POW, 1, m, &cBinop_0SyHrZZq_sendMessage);
  cMsg_WB34ia7Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_R7pIQA6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_TJWqoDAe, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_MZ9iBZ9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_opJmcrJE, 1, m, &cIf_opJmcrJE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_baESSRqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oJq2OSfD, HV_BINOP_GREATER_THAN, 1, m, &cBinop_oJq2OSfD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JI1wRZum, HV_BINOP_EQ, 1, m, &cBinop_JI1wRZum_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8MAw2tMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RMRh76UT, HV_BINOP_ADD, 0, m, &cBinop_RMRh76UT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RMRh76UT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HHfo7UOx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qq45qx5M_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oJq2OSfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R7pIQA6c, 1, m, &cIf_R7pIQA6c_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JI1wRZum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mkI5XVaK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_mkI5XVaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_TJWqoDAe, m);
}

void Heavy_WSTD_EQ::cCast_JbXDBryf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8MAw2tMg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_15BYHets_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RMRh76UT, HV_BINOP_ADD, 1, m, &cBinop_RMRh76UT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oJq2OSfD, HV_BINOP_GREATER_THAN, 0, m, &cBinop_oJq2OSfD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JI1wRZum, HV_BINOP_EQ, 0, m, &cBinop_JI1wRZum_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mE4peeV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ouQCCx9u, 0, m, &cVar_ouQCCx9u_sendMessage);
}

void Heavy_WSTD_EQ::cIf_uuYXohVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_SiSifHCm, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_np8bASjQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_D2vOlFzU, 0, m, &cSlice_D2vOlFzU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xmWE311t_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_D2vOlFzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NBjDn9kq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NBjDn9kq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_byzSx8EJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NBjDn9kq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_NBjDn9kq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OEw7lFEG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_xmWE311t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gbvdZScO, 0, m, &cSlice_gbvdZScO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Bx48vKiI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_gbvdZScO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_o7BQMtew_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_o7BQMtew_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_IkzaXePE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_o7BQMtew_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_o7BQMtew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bHT6b6Dk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_1jI01rvJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4oU8BmPZ, 0, m, &cSlice_4oU8BmPZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pTfcy5Rg_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_4oU8BmPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_blN2t0Iz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_blN2t0Iz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_1wRskdwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_blN2t0Iz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_blN2t0Iz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Kuql4jk9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_pTfcy5Rg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tmJ3b1S1, 0, m, &cSlice_tmJ3b1S1_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_tmJ3b1S1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LmuUKXyB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LmuUKXyB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_mmlnh2bU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LmuUKXyB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_LmuUKXyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mkKyLLlz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_O0LiZoDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VDPKMfIf, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_kf8Flxyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NAxZY5YG, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_r202wM2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UceFbHCP, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_CAIbbsgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uU4KbDMF, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_9SYF4zOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IOUokYM7, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_0wva5DTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_T69HgSB0_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_T69HgSB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1uO8ttU1, HV_BINOP_DIVIDE, 1, m, &cBinop_1uO8ttU1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sTheTmGI_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_STRl6kgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_sZVooem0_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_EpdOwKdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_STRl6kgG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sZVooem0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1uO8ttU1, HV_BINOP_DIVIDE, 0, m, &cBinop_1uO8ttU1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sTheTmGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EpdOwKdu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1uO8ttU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BCpYVaCD, HV_BINOP_MULTIPLY, 1, m, &cBinop_BCpYVaCD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BCpYVaCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DA83HgSb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_41kR27DW_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_SqjAffzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uMk1H9Ta_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_uyeIWQ65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EkGZinae_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_YTF2CSWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_WyeNVXjc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WyeNVXjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BCpYVaCD, HV_BINOP_MULTIPLY, 0, m, &cBinop_BCpYVaCD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aFiht55q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_dgSHul33_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dgSHul33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QYVhaIoD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_CRMbgxeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yZsWFK6G, 1, m, &cVar_yZsWFK6G_sendMessage);
}

void Heavy_WSTD_EQ::cVar_yZsWFK6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lv5SpBZX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_9kINDuy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aAuiAkSL, HV_BINOP_MULTIPLY, 1, m, &cBinop_aAuiAkSL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_e98PCDiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9kINDuy5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_El8B4UJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1P4prdUy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1P4prdUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0hl58HmR, HV_BINOP_MULTIPLY, 1, m, &cBinop_0hl58HmR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zmVBVJdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7dSsHz1C, HV_BINOP_MULTIPLY, 1, m, &cBinop_7dSsHz1C_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_77VE3DvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zmVBVJdL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3HeCxCHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BsHmd3fM, HV_BINOP_MULTIPLY, 1, m, &cBinop_BsHmd3fM_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_A6QL0N3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zUCBzMAO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zUCBzMAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eeDn9DA5, HV_BINOP_MULTIPLY, 1, m, &cBinop_eeDn9DA5_sendMessage);
}

void Heavy_WSTD_EQ::cVar_sSYg8iJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ryzkl05U_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_YTF2CSWN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l1MY571f_sendMessage);
}

void Heavy_WSTD_EQ::cVar_mbqZyJwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_aFiht55q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_41kR27DW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_uyeIWQ65_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DA83HgSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_SqjAffzt_sendMessage);
}

void Heavy_WSTD_EQ::cSend_uMk1H9Ta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yi3InJRN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_EkGZinae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ke1U2lvl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Pp9SoAgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_twno4ieP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_QYVhaIoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0c2mh4h4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0c2mh4h4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0SoLVLiQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_0SoLVLiQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0SoLVLiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Iiim16o6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Iiim16o6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Pp9SoAgD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_lv5SpBZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_u07SzRey_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_u07SzRey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FfbygPNC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CZGVMa5P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dhRfIv1m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GJbHEJ6W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GEbLAmlm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7Ri7u4Hb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aAuiAkSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O0LiZoDE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_0hl58HmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kf8Flxyw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_7dSsHz1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r202wM2G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_BsHmd3fM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CAIbbsgX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_eeDn9DA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9SYF4zOF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_EEGLkxBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sSYg8iJu, 0, m, &cVar_sSYg8iJu_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lEz0SY6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mbqZyJwK, 1, m, &cVar_mbqZyJwK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dhRfIv1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BsHmd3fM, HV_BINOP_MULTIPLY, 0, m, &cBinop_BsHmd3fM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GJbHEJ6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7dSsHz1C, HV_BINOP_MULTIPLY, 0, m, &cBinop_7dSsHz1C_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CZGVMa5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eeDn9DA5, HV_BINOP_MULTIPLY, 0, m, &cBinop_eeDn9DA5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7Ri7u4Hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aAuiAkSL, HV_BINOP_MULTIPLY, 0, m, &cBinop_aAuiAkSL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GEbLAmlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0hl58HmR, HV_BINOP_MULTIPLY, 0, m, &cBinop_0hl58HmR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FfbygPNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_l1MY571f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yZsWFK6G, 0, m, &cVar_yZsWFK6G_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ryzkl05U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mbqZyJwK, 0, m, &cVar_mbqZyJwK_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_L7ePTiSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xLcaJbNo, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_7s3y3D5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M3WYavmK, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_bXMVZvK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_urYy4T2c, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_KfbvpmmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_72L0f8HJ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_61bwlm8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7vs6cArX_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_7vs6cArX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iR6SIIOT, HV_BINOP_DIVIDE, 1, m, &cBinop_iR6SIIOT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LbQmp94O_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_kyN0sy8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_3b89peDy_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_25RHDB69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_kyN0sy8D_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3b89peDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iR6SIIOT, HV_BINOP_DIVIDE, 0, m, &cBinop_iR6SIIOT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LbQmp94O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_25RHDB69_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_iR6SIIOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0lvIEzf5, HV_BINOP_MULTIPLY, 1, m, &cBinop_0lvIEzf5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0lvIEzf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8dgh9d7l_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X8G0dehf_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_AdjQm68G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5yz1ny0N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_LQtttQRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FwgPNi5r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_BaTraDO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_jfE3wh0H_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jfE3wh0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0lvIEzf5, HV_BINOP_MULTIPLY, 0, m, &cBinop_0lvIEzf5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_40skbusv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_w1AZmNKM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_w1AZmNKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gXjBBaeq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_nJskdwZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XddxdLS8, HV_BINOP_MULTIPLY, 1, m, &cBinop_XddxdLS8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0EgJfFnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a4aKgJ4W, 1, m, &cVar_a4aKgJ4W_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0QfwYgUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UC1oB6G8, HV_BINOP_MULTIPLY, 1, m, &cBinop_UC1oB6G8_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_P4lfE5Xe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_IL2yiPIT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IL2yiPIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e1T0pJAG, HV_BINOP_MULTIPLY, 1, m, &cBinop_e1T0pJAG_sendMessage);
}

void Heavy_WSTD_EQ::cVar_a4aKgJ4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_azB2AGt1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_WlHXGxgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_49MrcZPZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_BaTraDO5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c77NGOZr_sendMessage);
}

void Heavy_WSTD_EQ::cVar_EsfPJMzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_40skbusv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_X8G0dehf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_LQtttQRr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8dgh9d7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_AdjQm68G_sendMessage);
}

void Heavy_WSTD_EQ::cSend_5yz1ny0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Yc6HlPda_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_FwgPNi5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PJ7uF7N1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_kXwK9MaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_58D2U5dy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_gXjBBaeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VFrl6gIW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VFrl6gIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LrzHYGhL, HV_BINOP_MULTIPLY, 1, m, &cBinop_LrzHYGhL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LrzHYGhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LYgkk1d9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LYgkk1d9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kXwK9MaI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_azB2AGt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EGO7Bzez_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EGO7Bzez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gaw9yBHX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6IR3RdyD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sgR71Fao_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FL0dZjxb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tjoCmQVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L7ePTiSO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_XddxdLS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7s3y3D5H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_UC1oB6G8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bXMVZvK4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_e1T0pJAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KfbvpmmI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_NJADlxsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WlHXGxgf, 0, m, &cVar_WlHXGxgf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_efTYFuqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EsfPJMzH, 1, m, &cVar_EsfPJMzH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_c77NGOZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a4aKgJ4W, 0, m, &cVar_a4aKgJ4W_sendMessage);
}

void Heavy_WSTD_EQ::cCast_49MrcZPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EsfPJMzH, 0, m, &cVar_EsfPJMzH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sgR71Fao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XddxdLS8, HV_BINOP_MULTIPLY, 0, m, &cBinop_XddxdLS8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6IR3RdyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UC1oB6G8, HV_BINOP_MULTIPLY, 0, m, &cBinop_UC1oB6G8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FL0dZjxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tjoCmQVJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_tjoCmQVJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Gaw9yBHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e1T0pJAG, HV_BINOP_MULTIPLY, 0, m, &cBinop_e1T0pJAG_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_VK0gofGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WLdnOEQN, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_R5E3yrfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_da6TPVh5, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_AUrkBKIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vo8griwJ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_LyOmdklS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dCXDzunI, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_3S61KT5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZHwLdgRy, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_0hTzmUUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2Qurlxna_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_2Qurlxna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kZnH8OCv, HV_BINOP_DIVIDE, 1, m, &cBinop_kZnH8OCv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DbgdWbsL_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_k8Vsia5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_hoFVTF7R_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_j9qXt4NB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_k8Vsia5L_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hoFVTF7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kZnH8OCv, HV_BINOP_DIVIDE, 0, m, &cBinop_kZnH8OCv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DbgdWbsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j9qXt4NB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_kZnH8OCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_um2abZ6U, HV_BINOP_MULTIPLY, 1, m, &cBinop_um2abZ6U_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_um2abZ6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fx4U18Sp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MxYt1Prv_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_XGikUfsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_C3PcbxjY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_N9RyxuBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0nteHOzk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_uctoNZi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_S6FX5sSR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_S6FX5sSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_um2abZ6U, HV_BINOP_MULTIPLY, 0, m, &cBinop_um2abZ6U_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_g6Sn2QMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_CUVL7C1E_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CUVL7C1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZnjK3z2z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_pAxNCYz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n1rQVqs6, HV_BINOP_MULTIPLY, 1, m, &cBinop_n1rQVqs6_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_MgeV1qMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_aTb5xCjK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aTb5xCjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pAxNCYz4_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_fpOa8uTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AuR0s46W_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AuR0s46W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_spnjEflm, HV_BINOP_MULTIPLY, 1, m, &cBinop_spnjEflm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qZ6E9mhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kpP5eTk4, HV_BINOP_MULTIPLY, 1, m, &cBinop_kpP5eTk4_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_9FheAsP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_m4DE9esX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_m4DE9esX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qZ6E9mhX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_H5wL3onI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PAyXHIGO, 1, m, &cVar_PAyXHIGO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GVDwAI0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QyEG76al, HV_BINOP_MULTIPLY, 1, m, &cBinop_QyEG76al_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_e7M6vl9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_58o4wios_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_58o4wios_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nYuBAHwK, HV_BINOP_MULTIPLY, 1, m, &cBinop_nYuBAHwK_sendMessage);
}

void Heavy_WSTD_EQ::cVar_PAyXHIGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PA3PltLE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Qashcxjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y4hEgBMI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_uctoNZi2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZD346Qu0_sendMessage);
}

void Heavy_WSTD_EQ::cVar_61uFgprC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_g6Sn2QMj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Fx4U18Sp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_XGikUfsX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MxYt1Prv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_N9RyxuBW_sendMessage);
}

void Heavy_WSTD_EQ::cSend_C3PcbxjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ndMvRUhL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_0nteHOzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6Yy4Ky77_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_GWveexbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_u3jSMjFK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ZnjK3z2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_J7B2sZzK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_J7B2sZzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L45KK4Bv, HV_BINOP_MULTIPLY, 1, m, &cBinop_L45KK4Bv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_L45KK4Bv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vK1aryBi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vK1aryBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GWveexbQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_PA3PltLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uspVmgnl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uspVmgnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_davrKjCt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Vv8ViuJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_voINO1km_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vTUm5ZqH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jfLpgv2g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fO5RZqZh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_n1rQVqs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VK0gofGj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_spnjEflm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R5E3yrfe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_kpP5eTk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AUrkBKIy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_QyEG76al_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LyOmdklS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_nYuBAHwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3S61KT5m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_7bOnItCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_61uFgprC, 1, m, &cVar_61uFgprC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_v6TTrIlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Qashcxjj, 0, m, &cVar_Qashcxjj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_voINO1km_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QyEG76al, HV_BINOP_MULTIPLY, 0, m, &cBinop_QyEG76al_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vTUm5ZqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kpP5eTk4, HV_BINOP_MULTIPLY, 0, m, &cBinop_kpP5eTk4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fO5RZqZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n1rQVqs6, HV_BINOP_MULTIPLY, 0, m, &cBinop_n1rQVqs6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jfLpgv2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_spnjEflm, HV_BINOP_MULTIPLY, 0, m, &cBinop_spnjEflm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_davrKjCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_2Vv8ViuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nYuBAHwK, HV_BINOP_MULTIPLY, 0, m, &cBinop_nYuBAHwK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZD346Qu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PAyXHIGO, 0, m, &cVar_PAyXHIGO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_y4hEgBMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_61uFgprC, 0, m, &cVar_61uFgprC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_q9XDrkLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uuYXohVA, 1, m, &cIf_uuYXohVA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_MnpOB8Op_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SiSifHCm, m);
}

void Heavy_WSTD_EQ::cBinop_ATtoKJPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MnpOB8Op_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Hj26ytLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uuYXohVA, 0, m, &cIf_uuYXohVA_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_LgxDr9hb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_K7pQzNTY, 0, m, &cSlice_K7pQzNTY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ESaG2P9b_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_K7pQzNTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mMjnPW14_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mMjnPW14_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_Svd4I9Tq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mMjnPW14_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_mMjnPW14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QGUZur1y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_DJLzb2rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YLfpHrEq_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_TUxanjzZ, 0, m, &cIf_TUxanjzZ_sendMessage);
}

void Heavy_WSTD_EQ::cIf_TUxanjzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Au0L4gKs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_C81QyYL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_voFDX38M_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_BMrW5aul_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_ZQZy6gB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zEuUU9zO, HV_BINOP_POW, 0, m, &cBinop_zEuUU9zO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zEuUU9zO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y9Yfwaeu, 0, m, &cIf_y9Yfwaeu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Yqaw6ulN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_uR6JTxO7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zfeNGkpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yk2PFmmR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JL7nGk4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_C81QyYL3, 0, m, &cIf_C81QyYL3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yk2PFmmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_C81QyYL3, 1, m, &cIf_C81QyYL3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BMrW5aul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Yqaw6ulN_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_voFDX38M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_y9Yfwaeu, 0, m, &cIf_y9Yfwaeu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uR6JTxO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zEuUU9zO, HV_BINOP_POW, 1, m, &cBinop_zEuUU9zO_sendMessage);
  cMsg_ZQZy6gB9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_y9Yfwaeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_VO7klY9S, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_YLfpHrEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TUxanjzZ, 1, m, &cIf_TUxanjzZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Au0L4gKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IAcgAxeG, HV_BINOP_GREATER_THAN, 1, m, &cBinop_IAcgAxeG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fo5GaMnU, HV_BINOP_EQ, 1, m, &cBinop_fo5GaMnU_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_RcywnmE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eGMewndX, HV_BINOP_ADD, 0, m, &cBinop_eGMewndX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eGMewndX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zfeNGkpn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JL7nGk4Z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IAcgAxeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y9Yfwaeu, 1, m, &cIf_y9Yfwaeu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fo5GaMnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hmjjjMqX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_hmjjjMqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_VO7klY9S, m);
}

void Heavy_WSTD_EQ::cCast_pOrZBMZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RcywnmE0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_XAAeIRMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DJLzb2rd, 0, m, &cVar_DJLzb2rd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YngziTwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eGMewndX, HV_BINOP_ADD, 1, m, &cBinop_eGMewndX_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IAcgAxeG, HV_BINOP_GREATER_THAN, 0, m, &cBinop_IAcgAxeG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fo5GaMnU, HV_BINOP_EQ, 0, m, &cBinop_fo5GaMnU_sendMessage);
}

void Heavy_WSTD_EQ::cVar_MFU9f6Ye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0qTH3saV_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_oE7k5D4t, 0, m, &cIf_oE7k5D4t_sendMessage);
}

void Heavy_WSTD_EQ::cIf_oE7k5D4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9SOOlBga_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_9R5LJhfb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_gn6bHv2q_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_XXIDtISr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_NwsXwAMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aP0CC0w7, HV_BINOP_POW, 0, m, &cBinop_aP0CC0w7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aP0CC0w7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oD87QKfF, 0, m, &cIf_oD87QKfF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yX4TmHQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Jmf6ezWQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5OwHRQE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9R5LJhfb, 0, m, &cIf_9R5LJhfb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7F7oCKQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AO4U0buB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AO4U0buB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9R5LJhfb, 1, m, &cIf_9R5LJhfb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XXIDtISr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_yX4TmHQB_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_gn6bHv2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_oD87QKfF, 0, m, &cIf_oD87QKfF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Jmf6ezWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aP0CC0w7, HV_BINOP_POW, 1, m, &cBinop_aP0CC0w7_sendMessage);
  cMsg_NwsXwAMc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_oD87QKfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nnddJU4M_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WDZeiumK_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_FaHP4WPe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_0qTH3saV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oE7k5D4t, 1, m, &cIf_oE7k5D4t_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9SOOlBga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jT7ni0tx, HV_BINOP_GREATER_THAN, 1, m, &cBinop_jT7ni0tx_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Llog3019, HV_BINOP_EQ, 1, m, &cBinop_Llog3019_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_SLhwi9vU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sdu1YPEu, HV_BINOP_ADD, 0, m, &cBinop_sdu1YPEu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sdu1YPEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7F7oCKQI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5OwHRQE3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jT7ni0tx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oD87QKfF, 1, m, &cIf_oD87QKfF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Llog3019_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IuUYKmDj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_IuUYKmDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nnddJU4M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WDZeiumK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_FaHP4WPe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Fwc0DMRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sdu1YPEu, HV_BINOP_ADD, 1, m, &cBinop_sdu1YPEu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jT7ni0tx, HV_BINOP_GREATER_THAN, 0, m, &cBinop_jT7ni0tx_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Llog3019, HV_BINOP_EQ, 0, m, &cBinop_Llog3019_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Ra2N0bKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SLhwi9vU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_h9R4cngF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MFU9f6Ye, 0, m, &cVar_MFU9f6Ye_sendMessage);
}

void Heavy_WSTD_EQ::cVar_5Hw9lIQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MTQ7LeQ1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_xiT1CkJJ, 0, m, &cIf_xiT1CkJJ_sendMessage);
}

void Heavy_WSTD_EQ::cIf_xiT1CkJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tulIkyI9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_qgcC9okp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Vvwh3Psl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_H36OO1aq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_fZzINhhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MTVw46FA, HV_BINOP_POW, 0, m, &cBinop_MTVw46FA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MTVw46FA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QUPpnjWw, 0, m, &cIf_QUPpnjWw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YXGg05fI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_eozbtPk7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zhqdaMgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qgcC9okp, 0, m, &cIf_qgcC9okp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AcScInlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_R6VlHglZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_R6VlHglZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qgcC9okp, 1, m, &cIf_qgcC9okp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_H36OO1aq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_YXGg05fI_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Vvwh3Psl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_QUPpnjWw, 0, m, &cIf_QUPpnjWw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eozbtPk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MTVw46FA, HV_BINOP_POW, 1, m, &cBinop_MTVw46FA_sendMessage);
  cMsg_fZzINhhY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_QUPpnjWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_m5fhGUVC, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_MTQ7LeQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xiT1CkJJ, 1, m, &cIf_xiT1CkJJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tulIkyI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x7cOCv7H, HV_BINOP_GREATER_THAN, 1, m, &cBinop_x7cOCv7H_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_21UojJAk, HV_BINOP_EQ, 1, m, &cBinop_21UojJAk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_vQiqhR3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2PSv0gJy, HV_BINOP_ADD, 0, m, &cBinop_2PSv0gJy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2PSv0gJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AcScInlw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zhqdaMgd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_x7cOCv7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QUPpnjWw, 1, m, &cIf_QUPpnjWw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_21UojJAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lHWEGEBW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_lHWEGEBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_m5fhGUVC, m);
}

void Heavy_WSTD_EQ::cCast_b6Yw7ASe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2PSv0gJy, HV_BINOP_ADD, 1, m, &cBinop_2PSv0gJy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_x7cOCv7H, HV_BINOP_GREATER_THAN, 0, m, &cBinop_x7cOCv7H_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_21UojJAk, HV_BINOP_EQ, 0, m, &cBinop_21UojJAk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6g2W2p8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5Hw9lIQC, 0, m, &cVar_5Hw9lIQC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QkAxngTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vQiqhR3A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_1KyLvB2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_rYyDPOsv, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_3jr2QZW5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rUPI5f3S, 0, m, &cSlice_rUPI5f3S_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JNPY9X9i_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_rUPI5f3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2UfSkv1j_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2UfSkv1j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_hotuMu41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2UfSkv1j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_2UfSkv1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pgxPhAPF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_JNPY9X9i_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CZczkq9r, 0, m, &cSlice_CZczkq9r_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LgxDr9hb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_CZczkq9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QrbMAMUS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QrbMAMUS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_mqpilcUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QrbMAMUS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_QrbMAMUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UUMzZcTV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_ESaG2P9b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Zxaf6mQK, 0, m, &cSlice_Zxaf6mQK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pHjKoHdv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_Zxaf6mQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KvEAAuIO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KvEAAuIO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_anRNxVaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KvEAAuIO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_KvEAAuIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BvvSnSiz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_pHjKoHdv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ccpEYZYm, 0, m, &cSlice_ccpEYZYm_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_ccpEYZYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UUr43LPI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UUr43LPI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_vMemoLW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UUr43LPI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_UUr43LPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dBs8RbBS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_pIrxHuvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LxThGQSg, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_CtlLDS5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gluMmNLA, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_CUTTHCoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kpo1BBSc, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_3CzcjGlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_msutQeJO, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_zIeCvAWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_D32j5R5I, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_KIQfqwO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fQwWgTD8_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_fQwWgTD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HRjQVkAL, HV_BINOP_DIVIDE, 1, m, &cBinop_HRjQVkAL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8yupvWnw_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_AH33Nl5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_HGuNeP9P_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_IzIWoXJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_AH33Nl5d_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HGuNeP9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HRjQVkAL, HV_BINOP_DIVIDE, 0, m, &cBinop_HRjQVkAL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8yupvWnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IzIWoXJs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_HRjQVkAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e6i3xj9i, HV_BINOP_MULTIPLY, 1, m, &cBinop_e6i3xj9i_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_e6i3xj9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GkanB1hZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X16O8bly_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_dCYT38Rv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ew3W4oEM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_OE1AQyQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QnJi5fli_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qk7Bk2I8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_63iYStRs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_63iYStRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e6i3xj9i, HV_BINOP_MULTIPLY, 0, m, &cBinop_e6i3xj9i_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_P6cFr1rz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_EFSHkhxj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EFSHkhxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kK8DoUCm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_PWFh5L6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oaTU3dwu, 1, m, &cVar_oaTU3dwu_sendMessage);
}

void Heavy_WSTD_EQ::cVar_oaTU3dwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u6GF3Syn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_x2zsjDOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zi1Ri1c3, HV_BINOP_MULTIPLY, 1, m, &cBinop_zi1Ri1c3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_o734B6BM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_x2zsjDOJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2PAcx9UE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MXnAnE5R_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MXnAnE5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EFke5nRx, HV_BINOP_MULTIPLY, 1, m, &cBinop_EFke5nRx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tcNONco4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JnmrMSAD, HV_BINOP_MULTIPLY, 1, m, &cBinop_JnmrMSAD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GPctfgLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tcNONco4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Fkn3J62V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4z1yH0Rf, HV_BINOP_MULTIPLY, 1, m, &cBinop_4z1yH0Rf_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_VuNr3GlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7SEI99ti_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7SEI99ti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KzSbLcLp, HV_BINOP_MULTIPLY, 1, m, &cBinop_KzSbLcLp_sendMessage);
}

void Heavy_WSTD_EQ::cVar_RfWoryZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LN6Ttq7e_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_qk7Bk2I8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UKvG33yk_sendMessage);
}

void Heavy_WSTD_EQ::cVar_knsTz29Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_P6cFr1rz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_X16O8bly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_OE1AQyQz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GkanB1hZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_dCYT38Rv_sendMessage);
}

void Heavy_WSTD_EQ::cSend_ew3W4oEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FRqbROLU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_QnJi5fli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wga74e5A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ESoABtic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ke9HtmH6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_kK8DoUCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8aUNPDiy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8aUNPDiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oNFkMcyf, HV_BINOP_MULTIPLY, 1, m, &cBinop_oNFkMcyf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oNFkMcyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jZpX1sgO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jZpX1sgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ESoABtic_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_u6GF3Syn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hfs40Zs2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hfs40Zs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8LE1sAj1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HyMocbrW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MmVjfSbl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AswwV8dD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fpOMYIm6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MekzQPkG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zi1Ri1c3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pIrxHuvB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_EFke5nRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CtlLDS5d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_JnmrMSAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CUTTHCoB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_4z1yH0Rf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3CzcjGlu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_KzSbLcLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zIeCvAWW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_XZZuZss8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RfWoryZj, 0, m, &cVar_RfWoryZj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZX7zhT1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_knsTz29Z, 1, m, &cVar_knsTz29Z_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MekzQPkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zi1Ri1c3, HV_BINOP_MULTIPLY, 0, m, &cBinop_zi1Ri1c3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fpOMYIm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EFke5nRx, HV_BINOP_MULTIPLY, 0, m, &cBinop_EFke5nRx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AswwV8dD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JnmrMSAD, HV_BINOP_MULTIPLY, 0, m, &cBinop_JnmrMSAD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HyMocbrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KzSbLcLp, HV_BINOP_MULTIPLY, 0, m, &cBinop_KzSbLcLp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MmVjfSbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4z1yH0Rf, HV_BINOP_MULTIPLY, 0, m, &cBinop_4z1yH0Rf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8LE1sAj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_UKvG33yk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oaTU3dwu, 0, m, &cVar_oaTU3dwu_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LN6Ttq7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_knsTz29Z, 0, m, &cVar_knsTz29Z_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_k4829p9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1m80Q8at, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ct8aEYMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UHRdj6b3, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_DlIcfTfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_quprpcAq, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_FfyK0TuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Loqi00Ap, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_7ysHfysq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sWABSubI_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_sWABSubI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_loVEeYpm, HV_BINOP_DIVIDE, 1, m, &cBinop_loVEeYpm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3FTTUwUB_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_4nAslNzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_vMzUQCE8_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_t5uMW9am_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_4nAslNzX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vMzUQCE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_loVEeYpm, HV_BINOP_DIVIDE, 0, m, &cBinop_loVEeYpm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_3FTTUwUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t5uMW9am_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_loVEeYpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hYdyiPJZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_hYdyiPJZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hYdyiPJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dbjEPUEU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_83XjpXNd_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_IAAujLrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UHimcngZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_C5PfGFws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dYGgemlo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_G9tHC20e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_cIGSYzOL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cIGSYzOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hYdyiPJZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_hYdyiPJZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rkBqdQti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_X8oiZZIf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_X8oiZZIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7hoHEleT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qrbIcvEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gWdWqtay, HV_BINOP_MULTIPLY, 1, m, &cBinop_gWdWqtay_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oqmv2iI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hGJ82PVy, 1, m, &cVar_hGJ82PVy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_y7WqqOkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ELjxC543, HV_BINOP_MULTIPLY, 1, m, &cBinop_ELjxC543_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_XNyMp7CO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Dj1pIYAU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Dj1pIYAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ExzWa19a, HV_BINOP_MULTIPLY, 1, m, &cBinop_ExzWa19a_sendMessage);
}

void Heavy_WSTD_EQ::cVar_hGJ82PVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YSoHurPe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_3bLx09g5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wAGWc3fC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_G9tHC20e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mqyh8r9x_sendMessage);
}

void Heavy_WSTD_EQ::cVar_zGzchjBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_rkBqdQti_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dbjEPUEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_IAAujLrs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_83XjpXNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_C5PfGFws_sendMessage);
}

void Heavy_WSTD_EQ::cSend_UHimcngZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Wbbd6JbF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_dYGgemlo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AYULEmFC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_SmKaZqUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UMSjAqQI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_7hoHEleT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5TEKVmVk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5TEKVmVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rE3HEx0M, HV_BINOP_MULTIPLY, 1, m, &cBinop_rE3HEx0M_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rE3HEx0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zMOk1izi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zMOk1izi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SmKaZqUg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_YSoHurPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xSFnkUtQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xSFnkUtQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KCnmrmAl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WplT49Un_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tfdE9mKf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zqpbDi3h_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oNsytOBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k4829p9h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gWdWqtay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ct8aEYMq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ELjxC543_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DlIcfTfx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ExzWa19a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FfyK0TuG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_Nuo4fuSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zGzchjBO, 1, m, &cVar_zGzchjBO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OlPCLNdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3bLx09g5, 0, m, &cVar_3bLx09g5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Mqyh8r9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hGJ82PVy, 0, m, &cVar_hGJ82PVy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wAGWc3fC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zGzchjBO, 0, m, &cVar_zGzchjBO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tfdE9mKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gWdWqtay, HV_BINOP_MULTIPLY, 0, m, &cBinop_gWdWqtay_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zqpbDi3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oNsytOBI, HV_BINOP_MULTIPLY, 0, m, &cBinop_oNsytOBI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WplT49Un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ELjxC543, HV_BINOP_MULTIPLY, 0, m, &cBinop_ELjxC543_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KCnmrmAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ExzWa19a, HV_BINOP_MULTIPLY, 0, m, &cBinop_ExzWa19a_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_H8BSt3MX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5EVc3t1N, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_QZdsEbcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6vOzTu2R, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_IwB04nwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W6nIBOJI, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_mP8sIe3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LsCXjWuy, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_q4wRt6uJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jXnJz9lh, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_iCWlP8Ul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sBkwQRNk_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_sBkwQRNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_12TMs3ge, HV_BINOP_DIVIDE, 1, m, &cBinop_12TMs3ge_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_stfwrHb8_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Dff2VMTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_jxHDJxWx_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_KcgOjJgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Dff2VMTq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jxHDJxWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_12TMs3ge, HV_BINOP_DIVIDE, 0, m, &cBinop_12TMs3ge_sendMessage);
}

void Heavy_WSTD_EQ::cCast_stfwrHb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KcgOjJgc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_12TMs3ge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6afRj0Sw, HV_BINOP_MULTIPLY, 1, m, &cBinop_6afRj0Sw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6afRj0Sw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y6Mql671_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gfwBcZXI_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_BLhZg9RY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6E7qHdST_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_R1nXDVmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BfEhvPcF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_X5f6eH4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_qUtFFJgx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qUtFFJgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6afRj0Sw, HV_BINOP_MULTIPLY, 0, m, &cBinop_6afRj0Sw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PLbeVXq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_8bGKisxh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8bGKisxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QVgq7clc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_JkkhgRff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wz9axmjp, HV_BINOP_MULTIPLY, 1, m, &cBinop_Wz9axmjp_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_GNn4semo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HK78TCKb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HK78TCKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JkkhgRff_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_yxRri70F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HqsTXllo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HqsTXllo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9NUdwEdo, HV_BINOP_MULTIPLY, 1, m, &cBinop_9NUdwEdo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Q6WS1HPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pp9odlVr, HV_BINOP_MULTIPLY, 1, m, &cBinop_Pp9odlVr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Xj4GgItm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jOJyEwPh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jOJyEwPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Q6WS1HPj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AAhyXzq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zPCDSip7, 1, m, &cVar_zPCDSip7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1cavxdg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IVaGoFR1, HV_BINOP_MULTIPLY, 1, m, &cBinop_IVaGoFR1_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_CxDB2Wqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CZluMWJn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CZluMWJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_snylNeej, HV_BINOP_MULTIPLY, 1, m, &cBinop_snylNeej_sendMessage);
}

void Heavy_WSTD_EQ::cVar_zPCDSip7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uer0gGvh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_jdFffESh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HFm0fO6I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_X5f6eH4N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gmXLonFH_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ogRMFewQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_PLbeVXq4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gfwBcZXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_R1nXDVmN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_y6Mql671_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_BLhZg9RY_sendMessage);
}

void Heavy_WSTD_EQ::cSend_6E7qHdST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MgIyOYEV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_BfEhvPcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_byagjLtb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_JYUpAyPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6mufYVyZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_QVgq7clc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_eJkHRPx8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eJkHRPx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WQA81ahN, HV_BINOP_MULTIPLY, 1, m, &cBinop_WQA81ahN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WQA81ahN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DllCtevG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DllCtevG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JYUpAyPn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_uer0gGvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JVaNzC6m_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JVaNzC6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6UTXFAzh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ft9yxzfS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YUwDimhr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NL1eY3XL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G08zKkxS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vS4AxX3X_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Wz9axmjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H8BSt3MX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_9NUdwEdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QZdsEbcR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Pp9odlVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IwB04nwh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_IVaGoFR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mP8sIe3U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_snylNeej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q4wRt6uJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_zVG6nGEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ogRMFewQ, 1, m, &cVar_ogRMFewQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_TddvM89F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jdFffESh, 0, m, &cVar_jdFffESh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NL1eY3XL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pp9odlVr, HV_BINOP_MULTIPLY, 0, m, &cBinop_Pp9odlVr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vS4AxX3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wz9axmjp, HV_BINOP_MULTIPLY, 0, m, &cBinop_Wz9axmjp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_G08zKkxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9NUdwEdo, HV_BINOP_MULTIPLY, 0, m, &cBinop_9NUdwEdo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ft9yxzfS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_snylNeej, HV_BINOP_MULTIPLY, 0, m, &cBinop_snylNeej_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YUwDimhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IVaGoFR1, HV_BINOP_MULTIPLY, 0, m, &cBinop_IVaGoFR1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6UTXFAzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_HFm0fO6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ogRMFewQ, 0, m, &cVar_ogRMFewQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gmXLonFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zPCDSip7, 0, m, &cVar_zPCDSip7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nnddJU4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1KyLvB2W, 1, m, &cIf_1KyLvB2W_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_W2Z4iRdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rYyDPOsv, m);
}

void Heavy_WSTD_EQ::cBinop_WDZeiumK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W2Z4iRdT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FaHP4WPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1KyLvB2W, 0, m, &cIf_1KyLvB2W_sendMessage);
}

void Heavy_WSTD_EQ::cVar_KzHQnDUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oPca7Boq, HV_BINOP_DIVIDE, 0, m, &cBinop_oPca7Boq_sendMessage);
}

void Heavy_WSTD_EQ::cVar_TCbEQD4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p8b3amA4, HV_BINOP_DIVIDE, 1, m, &cBinop_p8b3amA4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oPca7Boq, HV_BINOP_DIVIDE, 1, m, &cBinop_oPca7Boq_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_BBSKnBRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cbEsKfFC, HV_BINOP_DIVIDE, 0, m, &cBinop_cbEsKfFC_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_eAkyRZlh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cbEsKfFC, HV_BINOP_DIVIDE, 1, m, &cBinop_cbEsKfFC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IjCiRK7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KzHQnDUP, 0, m, &cVar_KzHQnDUP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_e7WfmGKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p8b3amA4, HV_BINOP_DIVIDE, 0, m, &cBinop_p8b3amA4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rySmxg4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TCbEQD4M, 0, m, &cVar_TCbEQD4M_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_p8b3amA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_BBSKnBRT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oPca7Boq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_eAkyRZlh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cbEsKfFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ev3Rw4qm_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_HXhyrRUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_ELFZKilK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tY5bBIKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_v7P9J8pB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ev3Rw4qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tY5bBIKl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v7P9J8pB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_HXhyrRUt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ELFZKilK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R3URWWoc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_cf1NJcH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_np8bASjQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3jr2QZW5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_4ckWfarA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_np8bASjQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3jr2QZW5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Stc4qpQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_np8bASjQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3jr2QZW5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_LivcMNfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_np8bASjQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3jr2QZW5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_R3URWWoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_np8bASjQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3jr2QZW5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_7yciC4Gy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_OESjRS3l, 0, m, &cVar_OESjRS3l_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_MYRXL80c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_gN6h8haz, 0, m, &cVar_gN6h8haz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ABh6uRbr, 0, m, &cVar_ABh6uRbr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ge9RbsKp, 0, m, &cVar_Ge9RbsKp_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_eg6cvHwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gN6h8haz, 0, m, &cVar_gN6h8haz_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_RdWe1MHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ABh6uRbr, 0, m, &cVar_ABh6uRbr_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_kOdBKszY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ge9RbsKp, 0, m, &cVar_Ge9RbsKp_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_n9RcMn9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WlHXGxgf, 0, m, &cVar_WlHXGxgf_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_mkKyLLlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_efTYFuqs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NJADlxsE_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_OEw7lFEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BrFPCtoO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MhHzfEU8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FwpNFXLD_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Kuql4jk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mE4peeV3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_15BYHets_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JbXDBryf_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_bHT6b6Dk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EmlboQtr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KIcSpDwc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SIEF7UIm_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Ob8l6MWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0wva5DTh_sendMessage(_c, 0, m);
  cMsg_61bwlm8w_sendMessage(_c, 0, m);
  cMsg_0hTzmUUY_sendMessage(_c, 0, m);
  cMsg_KIQfqwO5_sendMessage(_c, 0, m);
  cMsg_7ysHfysq_sendMessage(_c, 0, m);
  cMsg_iCWlP8Ul_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sSYg8iJu, 0, m, &cVar_sSYg8iJu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WlHXGxgf, 0, m, &cVar_WlHXGxgf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Qashcxjj, 0, m, &cVar_Qashcxjj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RfWoryZj, 0, m, &cVar_RfWoryZj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3bLx09g5, 0, m, &cVar_3bLx09g5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jdFffESh, 0, m, &cVar_jdFffESh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DZ1JxerT, 0, m, &cVar_DZ1JxerT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_B8a7JUe1, 0, m, &cVar_B8a7JUe1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_io7VuSB2, 0, m, &cVar_io7VuSB2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ouQCCx9u, 0, m, &cVar_ouQCCx9u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_byzSx8EJ, 0, m, &cVar_byzSx8EJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IkzaXePE, 0, m, &cVar_IkzaXePE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1wRskdwz, 0, m, &cVar_1wRskdwz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mmlnh2bU, 0, m, &cVar_mmlnh2bU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Svd4I9Tq, 0, m, &cVar_Svd4I9Tq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DJLzb2rd, 0, m, &cVar_DJLzb2rd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MFU9f6Ye, 0, m, &cVar_MFU9f6Ye_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5Hw9lIQC, 0, m, &cVar_5Hw9lIQC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hotuMu41, 0, m, &cVar_hotuMu41_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mqpilcUN, 0, m, &cVar_mqpilcUN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_anRNxVaC, 0, m, &cVar_anRNxVaC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vMemoLW1, 0, m, &cVar_vMemoLW1_sendMessage);
  cMsg_MYRXL80c_sendMessage(_c, 0, m);
  cMsg_7yciC4Gy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_yi3InJRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0SoLVLiQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_0SoLVLiQ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Ke1U2lvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_e98PCDiH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_El8B4UJ5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_77VE3DvF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_3HeCxCHG_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_twno4ieP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CRMbgxeZ_sendMessage);
  cMsg_A6QL0N3J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_Yc6HlPda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LrzHYGhL, HV_BINOP_MULTIPLY, 0, m, &cBinop_LrzHYGhL_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_PJ7uF7N1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_0QfwYgUo_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_58D2U5dy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tjoCmQVJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_tjoCmQVJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nJskdwZ0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0EgJfFnu_sendMessage);
  cMsg_P4lfE5Xe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_ndMvRUhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L45KK4Bv, HV_BINOP_MULTIPLY, 0, m, &cBinop_L45KK4Bv_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_6Yy4Ky77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MgeV1qMp_sendMessage(_c, 0, m);
  cMsg_fpOa8uTU_sendMessage(_c, 0, m);
  cMsg_9FheAsP1_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_GVDwAI0m_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_u3jSMjFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_H5wL3onI_sendMessage);
  cMsg_e7M6vl9T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_QGUZur1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3bLx09g5, 0, m, &cVar_3bLx09g5_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_dBs8RbBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Nuo4fuSQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OlPCLNdJ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_pgxPhAPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XAAeIRMo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YngziTwk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pOrZBMZx_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_BvvSnSiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6g2W2p8m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b6Yw7ASe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QkAxngTk_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_UUMzZcTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h9R4cngF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fwc0DMRE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ra2N0bKs_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_FRqbROLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oNFkMcyf, HV_BINOP_MULTIPLY, 0, m, &cBinop_oNFkMcyf_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_wga74e5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_o734B6BM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2PAcx9UE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GPctfgLx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Fkn3J62V_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ke9HtmH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PWFh5L6W_sendMessage);
  cMsg_VuNr3GlL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_Wbbd6JbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rE3HEx0M, HV_BINOP_MULTIPLY, 0, m, &cBinop_rE3HEx0M_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_AYULEmFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_y7WqqOkU_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_UMSjAqQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oNsytOBI, HV_BINOP_MULTIPLY, 1, m, &cBinop_oNsytOBI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qrbIcvEA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oqmv2iI2_sendMessage);
  cMsg_XNyMp7CO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_MgIyOYEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WQA81ahN, HV_BINOP_MULTIPLY, 0, m, &cBinop_WQA81ahN_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_byagjLtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GNn4semo_sendMessage(_c, 0, m);
  cMsg_yxRri70F_sendMessage(_c, 0, m);
  cMsg_Xj4GgItm_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_1cavxdg8_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_6mufYVyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_AAhyXzq1_sendMessage);
  cMsg_CxDB2Wqa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_aDo4vNAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OESjRS3l, 0, m, &cVar_OESjRS3l_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_5gbsBtbI, VOf(Bf0));
    __hv_varread_f(&sVarf_i0VqjcpW, VOf(Bf1));
    __hv_varread_f(&sVarf_559h1Yrq, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_BRgvXACv, VOf(Bf0));
    __hv_varread_f(&sVarf_oGu4r2Up, VOf(Bf1));
    __hv_varread_f(&sVarf_RqjDwdM2, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_VDPKMfIf, VOf(Bf0));
    __hv_line_f(&sLine_NAxZY5YG, VOf(Bf1));
    __hv_line_f(&sLine_UceFbHCP, VOf(Bf4));
    __hv_line_f(&sLine_uU4KbDMF, VOf(Bf5));
    __hv_line_f(&sLine_IOUokYM7, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_WV4oox60, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_eTZaZwKU, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_xLcaJbNo, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_M3WYavmK, VOf(Bf1));
    __hv_line_f(&sLine_urYy4T2c, VOf(Bf0));
    __hv_line_f(&sLine_72L0f8HJ, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_KPEMtLMM, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_SiSifHCm, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_WLdnOEQN, VOf(Bf7));
    __hv_line_f(&sLine_da6TPVh5, VOf(Bf1));
    __hv_line_f(&sLine_vo8griwJ, VOf(Bf4));
    __hv_line_f(&sLine_dCXDzunI, VOf(Bf6));
    __hv_line_f(&sLine_ZHwLdgRy, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_ZCyZ7xgD, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_TJWqoDAe, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_5gbsBtbI, VIf(Bf5));
    __hv_varwrite_f(&sVarf_i0VqjcpW, VIf(Bf0));
    __hv_varwrite_f(&sVarf_559h1Yrq, VIf(Bf6));
    __hv_line_f(&sLine_LxThGQSg, VOf(Bf6));
    __hv_line_f(&sLine_gluMmNLA, VOf(Bf0));
    __hv_line_f(&sLine_kpo1BBSc, VOf(Bf5));
    __hv_line_f(&sLine_msutQeJO, VOf(Bf8));
    __hv_line_f(&sLine_D32j5R5I, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_Js4HZYeo, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_VO7klY9S, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_1m80Q8at, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_UHRdj6b3, VOf(Bf0));
    __hv_line_f(&sLine_quprpcAq, VOf(Bf6));
    __hv_line_f(&sLine_Loqi00Ap, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_1R7rl3X0, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_rYyDPOsv, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_5EVc3t1N, VOf(Bf1));
    __hv_line_f(&sLine_6vOzTu2R, VOf(Bf0));
    __hv_line_f(&sLine_W6nIBOJI, VOf(Bf5));
    __hv_line_f(&sLine_LsCXjWuy, VOf(Bf4));
    __hv_line_f(&sLine_jXnJz9lh, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_TzICuMUo, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_m5fhGUVC, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_BRgvXACv, VIf(Bf8));
    __hv_varwrite_f(&sVarf_oGu4r2Up, VIf(Bf6));
    __hv_varwrite_f(&sVarf_RqjDwdM2, VIf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
